// ============================================================================
// Copyright (c) 2016 by Terasic Technologies Inc.
// ============================================================================
//
// Permission:
//
//   Terasic grants permission to use and modify this code for use
//   in synthesis for all Terasic Development Boards and Altera Development 
//   Kits made by Terasic.  Other use of this code, including the selling 
//   ,duplication, or modification of any portion is strictly prohibited.
//
// Disclaimer:
//
//   This VHDL/Verilog or C/C++ source code is intended as a design reference
//   which illustrates how these types of functions can be implemented.
//   It is the user's responsibility to verify their design for
//   consistency and functionality through the use of formal
//   verification methods.  Terasic provides no warranty regarding the use 
//   or functionality of this code.
//
// ============================================================================
//           
//  Terasic Technologies Inc
//  9F., No.176, Sec.2, Gongdao 5th Rd, East Dist, Hsinchu City, 30070. Taiwan
//  
//  
//                     web: http://www.terasic.com/  
//                     email: support@terasic.com
//
// ============================================================================
//Date:  Wed May 11 09:51:57 2016
// ============================================================================


module de10_lite_golden_top(

      ///////// Clocks /////////
      input              ADC_CLK_10,
      input              MAX10_CLK1_50,
      input              MAX10_CLK2_50,

      ///////// KEY /////////
      input    [ 1: 0]   KEY,

      ///////// SW /////////
      input    [ 9: 0]   SW,

      ///////// LEDR /////////
      output   [ 9: 0]   LEDR,

      ///////// HEX /////////
      output   [ 7: 0]   HEX0,
      output   [ 7: 0]   HEX1,
      output   [ 7: 0]   HEX2,
      output   [ 7: 0]   HEX3,
      output   [ 7: 0]   HEX4,
      output   [ 7: 0]   HEX5,

      ///////// SDRAM /////////
      output             DRAM_CLK,
      output             DRAM_CKE,
      output   [12: 0]   DRAM_ADDR,
      output   [ 1: 0]   DRAM_BA,
      inout    [15: 0]   DRAM_DQ,
      output             DRAM_LDQM,
      output             DRAM_UDQM,
      output             DRAM_CS_N,
      output             DRAM_WE_N,
      output             DRAM_CAS_N,
      output             DRAM_RAS_N,

      ///////// VGA /////////
      output             VGA_HS,
      output             VGA_VS,
      output   [ 3: 0]   VGA_R,
      output   [ 3: 0]   VGA_G,
      output   [ 3: 0]   VGA_B,

      ///////// Clock Generator I2C /////////
      output             CLK_I2C_SCL,
      inout              CLK_I2C_SDA,

      ///////// GSENSOR /////////
      output             GSENSOR_SCLK,
      inout              GSENSOR_SDO,
      inout              GSENSOR_SDI,
      input    [ 2: 1]   GSENSOR_INT,
      output             GSENSOR_CS_N,

      ///////// GPIO /////////
      inout    [35: 0]   GPIO,

      ///////// ARDUINO /////////
      inout    [15: 0]   ARDUINO_IO,
      input              ARDUINO_RESET_N 

);


//=======================================================
//  REG/WIRE declarations
//=======================================================

// system
wire						SYSTEM_Reset_n = ARDUINO_RESET_N;

//vga
wire 						VGA_CLK;
wire		[23:0] 		vga_rgb;

// Arduino TFT LCD display SPI port
wire		[15:0]		Arduino_GPIO;

wire						TFT_SPI_SCK;
wire						TFT_SPI_SDO;
wire						TFT_SPI_CS;
wire						TFT_SPI_DC;

//=======================================================
//  Structural coding
//=======================================================

// VGA
assign VGA_B = vga_rgb[7:4];
assign VGA_G = vga_rgb[15:12];
assign VGA_R = vga_rgb[23:20];

// G-sensor
assign GSENSOR_CS_N	= 1'b1;
assign GSENSOR_SDO	= 1'b0;


assign ARDUINO_IO[8]		= TFT_SPI_DC;
assign ARDUINO_IO[10]	= TFT_SPI_CS;
assign ARDUINO_IO[11]	= TFT_SPI_SDO;
assign ARDUINO_IO[13]	= TFT_SPI_SCK;


de10_lite_qsys u0 (
	.clk_clk											(ADC_CLK_10),		//		clk.clk
	.reset_reset_n									(SYSTEM_Reset_n),	//		reset.reset_n
	.clk_sdram_clk                         (DRAM_CLK),			// clk_sdram.clk     	
	.clk_vga_clk									(VGA_CLK),			//                      clk_vga.clk		

	.system_pll_areset_conduit_export		(),	//    system_pll_areset_conduit.export
	.system_pll_locked_conduit_export		(),	//    system_pll_locked_conduit.export
	.system_pll_phasedone_conduit_export	(),	// system_pll_phasedone_conduit.export

	// SDRAM
	.sdram_wire_addr                       (DRAM_ADDR),					// sdram_wire.addr
	.sdram_wire_ba                         (DRAM_BA),						//           .ba
	.sdram_wire_cas_n                      (DRAM_CAS_N),					//           .cas_n
	.sdram_wire_cke                        (DRAM_CKE),						//           .cke
	.sdram_wire_cs_n                       (DRAM_CS_N),					//           .cs_n
	.sdram_wire_dq                         (DRAM_DQ),						//           .dq
	.sdram_wire_dqm                        ({DRAM_UDQM,DRAM_LDQM}),	//           .dqm
	.sdram_wire_ras_n								(DRAM_RAS_N),					//           .ras_n
	.sdram_wire_we_n								(DRAM_WE_N),					//           .we_n

	// User Interface
	.pio_led_external_connection_export		(LEDR),							// pio_led_external_connection.export
	.pio_sw_external_connection_export		(SW),								// pio_sw_external_connection.export
	.pio_key_external_connection_export		(KEY),							// pio_button_external_connection.export	
	.seg7_conduit_end_export					({HEX5[7], HEX5[6:0], HEX4[7], HEX4[6:0],
														  HEX3[7], HEX3[6:0], HEX2[7], HEX2[6:0],
														  HEX1[7], HEX1[6:0], HEX0[7], HEX0[6:0]}),	//               seg7_conduit_end.export
	// VGA
	.alt_vip_itc_clocked_video_vid_clk       (VGA_CLK),			// alt_vip_itc_clocked_video.vid_clk
	.alt_vip_itc_clocked_video_vid_data      (vga_rgb),			//                          .vid_data
	.alt_vip_itc_clocked_video_underflow     (),						//                          .underflow
	.alt_vip_itc_clocked_video_vid_datavalid (),						//                          .vid_datavalid
	.alt_vip_itc_clocked_video_vid_v_sync    (VGA_VS),				//                          .vid_v_sync
	.alt_vip_itc_clocked_video_vid_h_sync    (VGA_HS),				//                          .vid_h_sync
	.alt_vip_itc_clocked_video_vid_f         (),						//                          .vid_f
	.alt_vip_itc_clocked_video_vid_h         (),						//                          .vid_h
	.alt_vip_itc_clocked_video_vid_v         (),						//                          .vid_v														  

	.arduino_spi_external_MISO					(),								//         arduino_spi_external.MISO
	.arduino_spi_external_MOSI					(TFT_SPI_SDO),				//                             .MOSI
	.arduino_spi_external_SCLK					(TFT_SPI_SCK),				//                             .SCLK
	.arduino_spi_external_SS_n					(TFT_SPI_CS),				//                             .SS_n
	.tft_spi_dc_export							(TFT_SPI_DC),                        //                   tft_spi_cd.export	
	.arduino_pio_external_export				(Arduino_GPIO),				//         arduino_pio_external.export	

	// G-sensor
	.g_sensor_i2c_scl_external_export		(GSENSOR_SCLK),		// g_sensor_i2c_scl_external.export
	.g_sensor_i2c_sda_external_export		(GSENSOR_SDI),			// g_sensor_i2c_sda_external.export
	.g_sensor_int_external_export				(~GSENSOR_INT),		// g_sensor_int_external.export
	
	// ADC
	.modular_adc_adc_pll_locked_export		()		// modular_adc_adc_pll_locked.export
	
	
	
	
);


endmodule
